@@ -1,8 +1,8 @@
 /*
- * Copyright (C) 2006, Mr Jamie McCracken (jamiemcc@gnome.org)
- * Copyright (C) 2007, Jason Kivlighn (jkivlighn@gmail.com)
- * Copyright (C) 2007, Creative Commons (http://creativecommons.org)
- * Copyright (C) 2008, Nokia
+ * Copyright (C) 2006, Jamie McCracken <jamiemcc@gnome.org>
+ * Copyright (C) 2007, Jason Kivlighn <jkivlighn@gmail.com>
+ * Copyright (C) 2007, Creative Commons <http://creativecommons.org>
+ * Copyright (C) 2008, Nokia <ivan.frade@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -1300,9 +1300,6 @@ create_decomposed_transient_metadata_tables (TrackerDBInterface *iface)
 
 			TrackerClass *domain;
 			const gchar *service_name;
-			const char *field_name;
-
-			field_name = tracker_property_get_name (property);
 
 			domain = tracker_property_get_domain (property);
 			service_name = tracker_class_get_name (domain);
@@ -1411,7 +1408,7 @@ get_new_service_id (TrackerDBInterface *iface)
 {
 	TrackerDBCursor    *cursor;
 	TrackerDBStatement *stmt;
-	gint max_service_id;
+	gint max_service_id = 0;
 
 	/* Don't intermix this thing with tracker_data_update_get_new_service_id,
 	 * if you use this, know what you are doing! */
@@ -1436,7 +1433,10 @@ gboolean
 tracker_data_manager_init (TrackerDBManagerFlags  flags,
                            const gchar          **test_schemas,
                            gboolean              *first_time,
-                           gboolean               journal_check)
+                           gboolean               journal_check,
+                           TrackerBusyCallback    busy_callback,
+                           gpointer               busy_user_data,
+                           const gchar           *busy_status)
 {
 	TrackerDBInterface *iface;
 	gboolean is_first_time_index, read_journal, check_ontology;
@@ -1516,7 +1516,8 @@ tracker_data_manager_init (TrackerDBManagerFlags  flags,
 
 		/* Start replay. Ontology changes might happen during replay of the journal. */
 
-		tracker_data_replay_journal (classes, properties, id_uri_map);
+		tracker_data_replay_journal (classes, properties, id_uri_map, 
+		                             busy_callback, busy_user_data, busy_status);
 
 		in_journal_replay = FALSE;
 
